===================================================
psy-strat: A psyplot plugin for stratigraphic plots
===================================================

.. start-badges

.. list-table::
    :stub-columns: 1
    :widths: 10 90

    * - docs
      - |docs|
    * - tests
      - |travis| |appveyor| |coveralls|
    * - package
      - |version| |conda| |supported-versions| |supported-implementations|

.. |docs| image:: http://readthedocs.org/projects/psy-strat/badge/?version=latest
    :alt: Documentation Status
    :target: http://psy-strat.readthedocs.io/en/latest/?badge=latest

.. |travis| image:: https://travis-ci.org/Chilipp/psy-strat.svg?branch=master
    :alt: Travis
    :target: https://travis-ci.org/Chilipp/psy-strat

.. |appveyor| image:: https://ci.appveyor.com/api/projects/status/pv9kyd8obfrqp5wf?svg=true
    :alt: AppVeyor
    :target: https://ci.appveyor.com/project/Chilipp/psy-strat

.. |coveralls| image:: https://coveralls.io/repos/github/Chilipp/psy-strat/badge.svg?branch=master
    :alt: Coverage
    :target: https://coveralls.io/github/Chilipp/psy-strat?branch=master

.. |version| image:: https://img.shields.io/pypi/v/psy-strat.svg?style=flat
    :alt: PyPI Package latest release
    :target: https://pypi.python.org/pypi/psy-strat

.. |conda| image:: https://anaconda.org/conda-forge/psy-strat/badges/version.svg
    :alt: conda
    :target: https://anaconda.org/conda-forge/psy-strat

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/psy-strat.svg?style=flat
    :alt: Supported versions
    :target: https://pypi.python.org/pypi/psy-strat

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/psy-strat.svg?style=flat
    :alt: Supported implementations
    :target: https://pypi.python.org/pypi/psy-strat

.. end-badges

Welcome to psy-strat! The interactive python package for the production of
stratigraphic plots (e.g. pollen diagrams).

To install this package, we recommend to use conda_ and install the package
via::

    $ conda install -c chilipp psy-strat

or use pip::

    $ pip install psy-strat

The full documentation is hosted at https://psy-strat.readthedocs.io

.. _conda: https://conda.io/miniconda.html
